@@ -1,4 +1,4 @@
-# Homology modeling by the automodel class
+# Comparative modeling by the automodel class
 from modeller import *              # Load standard Modeller classes
 from modeller.automodel import *    # Load the automodel class
 
@@ -23,4 +23,4 @@ a = MyModel(env,
 a.starting_model= 1                 # index of the first model
 a.ending_model  = 1                 # index of the last model
                                     # (determines how many models to calculate)
-a.make()                            # do the actual homology modeling
+a.make()                            # do the actual comparative modeling
