@@ -33,7 +33,7 @@ class molecular_dynamics(builtin_optimizer):
         self._modpt = _modeller.mod_md_optimizer_new(self)
 
     def __del__(self):
-        if self._modpt:
+        if self._modpt and _modeller:
             _modeller.mod_md_optimizer_free(self._modpt)
 
     def __get_optpt(self):
